@@ -25,11 +25,11 @@ Data::MoneyCurrency - Get currency information for different currencies
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 =head1 SYNOPSIS
@@ -336,7 +336,13 @@ sub get_currencies_for_country {
     croak "get_currency received no arguments" if @_ == 0;
     croak "get_currency received more than one argument" if @_ > 1;
     my $country = lc($_[0]);
-    return $rh_currencies_for_country->{$country};
+
+    # Return shallow copy to avoid mutating $rh_currencies_for_country
+    my $rv = $rh_currencies_for_country->{$country};
+    if ($rv) {
+        return [@$rv];
+    }
+    return;
 }
 
 =head1 AUTHOR
@@ -345,9 +351,9 @@ David D Lowe, C<< <daviddlowe.flimm at gmail.com> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-data-moneycurrency at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Data-MoneyCurrency>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+
+Please report any bugs or feature requests through the web interface at
+L<https://github.com/Flimm/perl5-Data-MoneyCurrency/issues>.
 
 =head1 SUPPORT
 
@@ -359,21 +365,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker (report bugs here)
+=item * Meta CPAN
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Data-MoneyCurrency>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Data-MoneyCurrency>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Data-MoneyCurrency>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Data-MoneyCurrency/>
+L<https://metacpan.org/pod/Data::MoneyCurrency>
 
 =back
 
